<?php
/*
Plugin Name: ChaCha Trends
Plugin URI: http://marketingtechblog.com/projects/chacha/
Description: A plugin for integrating <a href="http://www.chacha.com/?&utm_medium=Plugin&utm_campaign=WordPress" target="_blank">ChaCha</a> to your WordPress Blog and to get the latest trends from ChaCha, Twitter and Google to your Dashboard.
Version: 2.1.1
Author: Douglas Karr
Author URI: http://www.dknewmedia.com/
*/

load_plugin_textdomain('wpcc', $path = 'wp-content/plugins/ChaCha');

// Check to ensure that the user has PHP 5 or greater
define('CHACHA_COMPATIBLE', version_compare(phpversion(), '5', '>='));
if (!CHACHA_COMPATIBLE) {
	trigger_error('ChaCha requires PHP 5 or greater.', E_USER_ERROR);
}

// Include WordPress RSS capabilities
include_once(ABSPATH . WPINC . '/feed.php');
// Include the widget to ask a question to ChaCha
include_once(dirname(__FILE__).'/widget_ask.php');
// Include the widget to get the latest questions in a ChaCha topic of your choice
include_once(dirname(__FILE__).'/widget_topics.php');
// Include the widget to get the latest ChaCha trends
include_once(dirname(__FILE__).'/widget_trends.php');
// Include the widget to get the latest ChaCha questions with a keyword of your choice
include_once(dirname(__FILE__).'/widget_search.php');
// Include the functions to retrieve trending data from ChaCha, Twitter and Google
include_once(dirname(__FILE__).'/admin_trends.php');

// Add the menus to WordPress
function wpcc_addchacha() {
	// Adds the Trends Menu > ChaCha Trends Option
	if (function_exists('add_menu_page')) {
		$page = add_submenu_page('index.php', __('ChaCha Trends'), __('ChaCha Trends'), '0', 'ChaCha', 'wpcc_addchachatrends_page');
		add_action('admin_print_scripts-'.$page, 'wpcc_javascript');
	}
	// Adds the Settings Menu > ChaCha Option
	if (function_exists('add_options_page')) {
		$settings = add_options_page('ChaCha', 'ChaCha', 'administrator', __FILE__, 'wpcc_addchachaadmin_page');
		add_action('admin_print_scripts-'.$settings, 'wpcc_javascript');
    }
}

// Specify the location of the admin page
function wpcc_addchachaadmin_page() {
    include(dirname(__FILE__).'/admin.php');
}
// Specify the location of the trends page
function wpcc_addchachatrends_page() {
    include(dirname(__FILE__).'/trends.php');
}

// Add tracking code to observe usage in the footer
function wpcc_code() {
	$wpcc_track = get_option('wpcc_track');
	if($wpcc_track == "TRUE") {
		echo "\n".'<!-- Begin ChaCha WordPress Plugin Usage Stats-->';
		echo "<iframe src='http://www.chacha.com/wordpressAnalytics.html' height='1px' width='1px'></iframe>";
		echo '<!-- End ChaCha -->'."\n";
	}
}

// General request function with cURL
function wpccRequest($apikey, $url) {
	// create a new cURL resource
	$ch = curl_init();
	curl_setopt($ch, CURLOPT_URL, $url);
	curl_setopt($ch, CURLOPT_HEADER, 0);
	curl_setopt($ch, CURLOPT_TIMEOUT, 30);
	curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
	curl_setopt($ch, CURLOPT_HTTPHEADER, array('apikey:'.$apikey));
	$referrer = get_option('siteurl');
	curl_setopt($ch, CURLOPT_REFERER, $referrer);
	$output = curl_exec($ch);
	curl_close($ch);
	return $output;
}

// Load jQuery in the User Interface for Ajax Calls
function wpcc_javascript() {
	wp_enqueue_script('wpcc_jqry');
}
function wpcc_getchachaWidget_jquery() {
	wp_enqueue_script('jQuery'); 
}

// Register each of the Widgets
function wpcc_chachaInit() {
	register_widget('wpcc_chachaWidgetSearch');
	register_widget('wpcc_chachaWidgetTrends');
	register_widget('wpcc_chachaWidgetTopic');
	register_widget('wpcc_chachaWidgetAsk');
}

// Load the javascript includes in the User Interface for the streaming RSS
function wpcc_ctrotator_scripts ( ) {
  wp_enqueue_script( "ctrotator", path_join(WP_PLUGIN_URL, basename( dirname( __FILE__ ) )."/js/jquery.ctrotator.js"), array( 'jquery' ) );
  wp_enqueue_script( "ctrotator-li", path_join(WP_PLUGIN_URL, basename( dirname( __FILE__ ) )."/js/jquery.ctrotator.bridge.li.js"), array( 'jquery' ) );
  wp_enqueue_script( "tooltip", path_join(WP_PLUGIN_URL, basename( dirname( __FILE__ ) )."/js/jquery.tooltip.min.js"), array( 'jquery' ) );
}
	
function wpcc_getchachaWidget_js() {
	// Loads the SACK transport for making AJAX calls
	wp_print_scripts( array( 'sack' ));
	?>
	<script type="text/javascript">
	//<![CDATA[
	function getChaCha( query, results_div, action) {
		var mysack = new sack("<?php bloginfo( 'wpurl' ); ?>/wp-admin/admin-ajax.php" );    
		mysack.execute = 1;
		mysack.method = 'POST';
		mysack.setVar( "action", action );
  		mysack.setVar( "query", query.value );
  		mysack.setVar( "results_div_id", results_div );
		mysack.onError = function() { var resp = 'There was a problem with your request';};
		mysack.runAJAX();
		return true;
	}
	//]]>
	</script>
	<?php
}

function genRandStr($minLen, $maxLen, $alphaLower = 1, $alphaUpper = 1, $num = 1, $batch = 1) {
    
    $alphaLowerArray = array('a', 'b', 'c', 'd', 'e', 'f', 'g', 'h', 'i', 'j', 'k', 'l', 'm', 'n', 'o', 'p', 'q', 'r', 's', 't', 'u', 'v', 'w', 'x', 'y', 'z');
    $alphaUpperArray = array('A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I', 'J', 'K', 'L', 'M', 'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V', 'W', 'X', 'Y', 'Z');
    $numArray = array(0, 1, 2, 3, 4, 5, 6, 7, 8, 9);
    
    if (isset($minLen) && isset($maxLen)) {
        if ($minLen == $maxLen) {
            $strLen = $minLen;
        } else {
            $strLen = rand($minLen, $maxLen);
        }
        $merged = array_merge($alphaLowerArray, $alphaUpperArray, $numArray);
        
        if ($alphaLower == 1 && $alphaUpper == 1 && $num == 1) {
            $finalArray = array_merge($alphaLowerArray, $alphaUpperArray, $numArray);
        } elseif ($alphaLower == 1 && $alphaUpper == 1 && $num == 0) {
            $finalArray = array_merge($alphaLowerArray, $alphaUpperArray);
        } elseif ($alphaLower == 1 && $alphaUpper == 0 && $num == 1) {
            $finalArray = array_merge($alphaLowerArray, $numArray);
        } elseif ($alphaLower == 0 && $alphaUpper == 1 && $num == 1) {
            $finalArray = array_merge($alphaUpperArray, $numArray);
        } elseif ($alphaLower == 1 && $alphaUpper == 0 && $num == 0) {
            $finalArray = $alphaLowerArray;
        } elseif ($alphaLower == 0 && $alphaUpper == 1 && $num == 0) {
            $finalArray = $alphaUpperArray;                        
        } elseif ($alphaLower == 0 && $alphaUpper == 0 && $num == 1) {
            $finalArray = $numArray;
        } else {
            return FALSE;
        }
        
        $count = count($finalArray);
        
        if ($batch == 1) {
            $str = '';
            $i = 1;
            while ($i <= $strLen) {
                $rand = rand(0, $count);
                $newChar = $finalArray[$rand];
                $str .= $newChar;
                $i++;
            }
            $result = $str;
        } else {
            $j = 1;
            $result = array();
            while ($j <= $batch) { 
                $str = '';
                $i = 1;
                while ($i <= $strLen) {
                    $rand = rand(0, $count);
                    $newChar = $finalArray[$rand];
                    $str .= $newChar;
                    $i++;
                }
                $result[] = $str;
                $j++;
            }
        }
        
        return $result;
    }
}

add_action('init', 'wpcc_getchachaWidget_jquery');
add_action('wp_head', 'wpcc_getchachaWidget_js' );
add_action('admin_menu', 'wpcc_addchacha');
add_action('wp_footer','wpcc_code',90);
add_action('wp_ajax_wpcc_getchacha', 'wpcc_getchacha' );
add_action('wp_ajax_wpcc_getgoogle', 'wpcc_getgoogle' );
add_action('wp_ajax_wpcc_gettwitter', 'wpcc_gettwitter' );
add_action('wp_ajax_wpcc_gettweets', 'wpcc_gettweets' );
add_action('wp_ajax_wpcc_getchachaWidgetTrends', 'wpcc_getchachaWidgetTrends_callback');
add_action('wp_ajax_nopriv_wpcc_getchachaWidgetTrends', 'wpcc_getchachaWidgetTrends_callback');
add_action('wp_ajax_wpcc_getchachaWidgetAsk', 'wpcc_getchachaWidgetAsk_callback');
add_action('wp_ajax_nopriv_wpcc_getchachaWidgetAsk', 'wpcc_getchachaWidgetAsk_callback');
add_action('wp_ajax_wpcc_getchachaWidgetTopic', 'wpcc_getchachaWidgetTopic_callback');
add_action('wp_ajax_nopriv_wpcc_getchachaWidgetTopic', 'wpcc_getchachaWidgetTopic_callback');
add_action('wp_ajax_wpcc_getchachaWidgetSearch', 'wpcc_getchachaWidgetSearch_callback');
add_action('wp_ajax_nopriv_wpcc_getchachaWidgetSearch', 'wpcc_getchachaWidgetSearch_callback');
add_action('admin_header', 'wpcc_javascript');
add_action('wp_print_scripts', 'wpcc_ctrotator_scripts');
add_action('widgets_init', 'wpcc_chachaInit');
?>